@@ -2,21 +2,28 @@ import numpy as np
 import cv2
 from .deep_sort import *
 from .generate_detections import *
+from .utils import download_file
 
 max_cosine_distance = 0.3
 nn_budget = None
 nms_max_overlap = 1.0
 tracking = True
-
+dest_dir = os.path.expanduser('~') + os.path.sep + '.deepvision' + os.path.sep + 'object_detection' + os.path.sep + 'yolo' + os.path.sep + 'yolov3'
 
 # Deep SORT
-model_filename = 'model_data/mars-small128.pb'
-encoder = create_box_encoder(model_filename, batch_size=1)
+model_filename = 'mars-small128.pb'
+model_path = dest_dir + os.path.sep + model_filename
+cfg_url = 'https://github.com/Lynchez/deepvision/raw/master/model_data/mars-small128.pb'
 
-metric = nn_matching.NearestNeighborDistanceMetric("cosine", max_cosine_distance, nn_budget)
+if not os.path.exists(model_path):
+    download_file(url=cfg_url, file_name=model_filename, dest_dir=dest_dir)
+
+encoder = create_box_encoder(model_path, batch_size=1)
+metric = NearestNeighborDistanceMetric("cosine", max_cosine_distance, nn_budget)
 tracker = Tracker(metric)
 
 def Track(boxes, classes, confidence, frame):
+
     if tracking:
         features = encoder(frame, boxes)
 
